import React from 'react';
import {connect} from 'react-redux';
import CSVForm from './csv-form';
import Loader from '../loader';
import {
  getNodeTagsAction,
  vulnerabilityCSVDownloadAction,
} from '../../actions/app-actions';

class CSVModal extends React.PureComponent {
  constructor(props) {
    super(props);
    this.handleDownloadCSV = this.handleDownloadCSV.bind(this);
    this.getNodeTags = this.getNodeTags.bind(this);
  }

  componentDidMount() {
    this.getNodeTags();
  }

  handleDownloadCSV(valuesIm) {
    const {
      vulnerabilityCSVDownloadAction: action,
    } = this.props;
    const values = valuesIm.toJS();
    action(values);
  }

  getNodeTags() {
    const {
      getNodeTagsAction: action,
    } = this.props;
    return action();
  }

  render() {
    const {
      nodeTags,
      loading,
    } = this.props;
    return (
      <div>
        {loading && (
        <div className="loader">
          <Loader small style={{left: '50%', top: '50%'}} />
        </div>
        )}
        <CSVForm
          onSubmit={this.handleDownloadCSV}
          nodeTags={nodeTags}
        />
      </div>
    );
  }
}

const mapStateToProps = state => ({
  nodeTags: state.get('node_tags'),
  loading: state.getIn(['report_download', 'cve', 'loading']),
});

export default connect(mapStateToProps, {
  getNodeTagsAction,
  vulnerabilityCSVDownloadAction,
})(CSVModal);
