import React from 'react';
import {connect} from 'react-redux';
import CVEStatsPerImage from './cve-stats-per-image';
import Loader from '../loader';

const loaderStyle = {
  top: '20%',
  left: '49.5%',
};

class CVEImageReportContainer extends React.PureComponent {
  render() {
    const {
      reportView, imageName, scanId, ...rest
    } = this.props;
    const report = reportView.get('report') || {};
    const data = report[scanId];
    const initiatedByPollable = reportView.get('initiatedByPollable');
    const loading = reportView.get('loading') && !initiatedByPollable && !data;
    return (
      <div className="relative">
        {loading
          && (
          <Loader
            small
            style={loaderStyle}
          />
          )
        }
        <CVEStatsPerImage
          data={data}
          imageName={imageName}
          scanId={scanId}
          {...rest}
        />
      </div>
    );
  }
}

function mapStateToProps(state) {
  const reportView = state.getIn(['cve', 'image_report_view']);
  return {
    reportView,
  };
}

export default connect(mapStateToProps)(CVEImageReportContainer);
