/* eslint-disable camelcase */
import React from 'react';
import {connect} from 'react-redux';
import {reduxForm, Field, formValueSelector} from 'redux-form/immutable';
import {Map} from 'immutable';
import {CVE_SCAN_TYPE_OPTIONS} from '../../../constants/menu-collection';
import Loader from '../../common/app-loader/horizontal-dots-loader';
import ToggleSwitchField from '../../common/toggle-switch/redux-form-field';
import {
  clearScanContainerImageRegistryAction,
} from '../../../actions/app-actions';

const priorityOption = [
  {
    value: 'priority',
    label: 'Priority Scan',
  },
];

const renderCheckboxGroupField = ({input, meta, options}) => {
  const {name, onChange} = input;
  const {touched, error} = meta;
  const inputValue = input.value;

  const checkboxes = options.map(({label, value, disabled}, index) => {
    const handleChange = (event) => {
      const arr = [...inputValue];
      if (event.target.checked) {
        arr.push(value);
      } else {
        arr.splice(arr.indexOf(value), 1);
      }
      return onChange(arr);
    };
    const checked = inputValue.includes(value);
    return (
      <div className="df-checkbox-button" key={label}>
        <input
          type="checkbox"
          name={`${name}[${index}]`}
          id={`${name}[${index}]`}
          value={value}
          checked={checked}
          onChange={handleChange}
          disabled={disabled}
        />
        <label htmlFor={`${name}[${index}]`}>
          <span>{label}</span>
        </label>
      </div>
    );
  });

  return (
    <div>
      <div className="df-checkbox-group">{checkboxes}</div>
      {touched && error && <p className="error">{error}</p>}
    </div>
  );
};

class CVEScanForm extends React.PureComponent {
  constructor(props) {
    super(props);
    this.state = {};
    this.submitClickHandler = this.submitClickHandler.bind(this);
  }

  componentDidMount() {
    const {
      clearScanContainerImageRegistryAction: clearAction,
    } = this.props;
    clearAction();
  }

  UNSAFE_componentWillReceiveProps(newProps) {
    const {
      change,
      toggleAll,
    } = this.props;
    if (toggleAll !== newProps.toggleAll) {
      if (newProps.toggleAll) {
        change('scanType', CVE_SCAN_TYPE_OPTIONS.map(el => el.value));
      } else {
        change('scanType', ['base', 'java']);
      }
    }
  }

  submitClickHandler(values) {
    const {handleSubmit} = this.props;
    return handleSubmit(values);
  }

  toggleState() {
    const { showAdvancedOptions } = this.state;
    this.setState(
      {showAdvancedOptions: !showAdvancedOptions},
    );
  }

  render() {
    const {
      submitting,
      userDefinedTags,
      loading = false,
      message,
      errorMessage,
      scheduleInterval,
    } = this.props;
    const tagList = userDefinedTags ? userDefinedTags.split(',') : [];
    const tagOptions = tagList.map(el => ({
      label: el,
      value: el,
    }));

    const showAdvancedOptionsLink = tagOptions.length > 0;
    const {
      showAdvancedOptions,
    } = this.state;
    const scanButtonLabel = scheduleInterval?.length ? 'Schedule Scan' : 'Scan Now';
    const languageOptions = CVE_SCAN_TYPE_OPTIONS;
    return (
      <div className="node-cve">
        <div className="cve-scan-form">
          <div className="title">
            Start a new scan
          </div>
          <form onSubmit={this.submitClickHandler} autoComplete="off">
            <Field
              name="toggle"
              component={ToggleSwitchField}
              label="Select All"
            />
            <div className="form-field">
              <input
                type="checkbox"
                checked
                disabled
              />
              <span className="label">
                OS Packages
              </span>
            </div>
            <Field
              component={renderCheckboxGroupField}
              options={languageOptions}
              name="scanType"
            />
            {showAdvancedOptionsLink && (
            <div className="form-field">
              <span
                onClick={this.toggleState}
                className="link"
                aria-hidden="true"
              >
                <i className={`fa ${showAdvancedOptions ? 'fa-caret-down' : 'fa-caret-right'}`} />&nbsp;&nbsp;Advanced Options
              </span>
            </div>
            )}
            {showAdvancedOptions && (
            <div className="form-field">
              <div className="sub-heading"> Start scan on all nodes with the chosen tags </div>
              <Field
                component={renderCheckboxGroupField}
                options={tagOptions}
                name="taglist"
               />
            </div>
            )}
            <div style={{marginTop: '10px', marginBottom: '10px'}}>
              <Field
                component={renderCheckboxGroupField}
                options={priorityOption}
                name="priority"
              />
            </div>
            <div className="form-field">
              <span className="label">
                Scan Interval in days (optional)
              </span>
              <Field
                component="input"
                type="text"
                name="scheduleInterval"
              />
            </div>
            <div className="form-field">
              <button
                className="primary-btn full-width relative"
                type="submit"
                disabled={submitting}
               >
                {scanButtonLabel}
              </button>
              {loading && <Loader style={{ right: '4%', top: '0%'}} />}
            </div>
            <div>
              {message
                && (
                <span className="message">
                  {message}
                </span>
                )
              }
              {errorMessage
                && (
                <span className="error-message">
                  {errorMessage}
                </span>
                )
              }
            </div>
          </form>
        </div>
      </div>
    );
  }
}

const cveScanFormSelector = formValueSelector('cve-scan');
const mapStateToProps = state => ({
  loading: state.getIn(['cve', 'container_image_registry', 'scan_registry', 'loading']),
  errorMessage: state.getIn(['cve', 'container_image_registry', 'scan_registry', 'error', 'message']),
  message: state.getIn(['cve', 'container_image_registry', 'scan_registry', 'message']),
  toggleAll: cveScanFormSelector(state, 'toggle'),
  scheduleInterval: cveScanFormSelector(state, 'scheduleInterval'),
});

export default reduxForm({
  form: 'cve-scan',
  initialValues: Map({
    scanType: ['base', 'java'],
  }),
})(connect(mapStateToProps, {
  clearScanContainerImageRegistryAction,
})(CVEScanForm));
